pub struct Processor<'processor> {
    pub storage: Option<Box<dyn RadStorage>>,
    /* private fields */
}
Processor that parses(lexes) given input and print out to desginated output

Fields

storage: Option<Box<dyn RadStorage>>

Implementations

Creates default processor with default macros

Creates default processor without default macros

Set write option to yield output to the file

Write to variable

Yield error to the file

Yield error to the file

Custom comment character

Custom macro character

Use unix line ending instead of operating system’s default one

Set purge option

Set lenient

Set hygiene variant

Set truncate option

Set comment type

Set silent option

Set nopanic

Set assertion mode

Melt rule file

This always melt file into non-volatile form

Melt rule as literal input source, or say from byte array

Open authorization of processor

Open authorization of processor but yield warning

Discard output

Build with storage

Set queue object

Set hygiene type

This also clears volatile runtime macro at the same time.

Clear volatile macros

Toggle macro hygiene

Set write option in the process

Check if processing is on caching state

Toggle cache option

Set write option in the process

Print current permission status

Print the result of a processing

Clear cached and organze multiple jobs

    • clear volatile macors
    • Check if there is any unterminated job Return cached string, if cache was not empty

Set storage

Extract from storage

Freeze to a single file

Frozen file is a bincode encoded binary format file.

Add a new macro as an extension

Add runtime rules without builder pattern

Args

The order of argument is “name, args, body”

Example
processor.add_runtime_rules(vec![("macro_name","macro_arg1 macro_arg2","macro_body=$macro_arg1()")]);

Add static rules without builder pattern

Args

The order of argument is “name, body”

Example
processor.add_static_rules(vec![("macro_name","Macro body without arguments")]);

Read from string

Read from standard input

If debug mode is enabled this, doesn’t read stdin line by line but by chunk because user input is also a standard input and processor cannot distinguish the two

Process contents from a file

Check auth information

This will print log_error if auth was enabled with warning

@return If auth is enabled or not

Expand given text

Check if given macro exists

Try undefine macro

Rename macro

Append content into a macro

Replace macro’s content

Add new local macro

Remove local macro

Check if given text is boolean-able