Struct rad::Processor[][src]

pub struct Processor { /* fields omitted */ }

Implementations

Creates new processor with deafult options

Set write option to yield output to the file

Yield error to the file

Use unix line ending instead of os default one

Set greedy option

Set purge option

Set strict option

Set silent option

Add custom rules

Creates a unreferenced instance of processor

Print the result of a processing

Freeze to single file

Read from string

Read from standard input

Process contents from a file

Log error

Log warning

Add custom rules without builder pattern