Struct rad::Processor [−][src]
pub struct Processor { /* fields omitted */ }Implementations
Set write option to yield output to the file
Yield error to the file
Use unix line ending instead of os default one
Add custom rules
Print the result of a processing
Read from standard input
Process contents from a file
Add custom rules without builder pattern